# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/nft/module/v1/module.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/nft/module/v1/module.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/nft/module/v1/module.proto\x12\x14\x63osmos.nft.module.v1\x1a cosmos/app/v1alpha1/module.proto\"$\n\x06Module:\x1a\xba\xc0\x96\xda\x01\x14\n\x12\x63osmossdk.io/x/nftB\x9a\x01\n\x18\x63om.cosmos.nft.module.v1B\x0bModuleProtoP\x01\xa2\x02\x03\x43NM\xaa\x02\x14\x43osmos.Nft.Module.V1\xca\x02\x14\x43osmos\\Nft\\Module\\V1\xe2\x02 Cosmos\\Nft\\Module\\V1\\GPBMetadata\xea\x02\x17\x43osmos::Nft::Module::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.cosmos.nft.module.v1B\013ModuleProtoP\001\242\002\003CNM\252\002\024Cosmos.Nft.Module.V1\312\002\024Cosmos\\Nft\\Module\\V1\342\002 Cosmos\\Nft\\Module\\V1\\GPBMetadata\352\002\027Cosmos::Nft::Module::V1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001\024\n\022cosmossdk.io/x/nft'
  _globals['_MODULE']._serialized_start=93
  _globals['_MODULE']._serialized_end=129
# @@protoc_insertion_point(module_scope)
